aboutsummaryrefslogtreecommitdiff
path: root/site/docs
diff options
context:
space:
mode:
authorJohann-S <[email protected]>2018-11-08 16:22:45 +0100
committerXhmikosR <[email protected]>2018-11-08 17:22:45 +0200
commit1fdc7819cdc0cdbd0cb15ecc9d9b9324dd3902c3 (patch)
tree14835d5f177eaae766dcb4a5a96c6def06717e02 /site/docs
parent2df2cdd33d6b36a18882d0c1e1ecc823a0468468 (diff)
downloadbootstrap-1fdc7819cdc0cdbd0cb15ecc9d9b9324dd3902c3.tar.xz
bootstrap-1fdc7819cdc0cdbd0cb15ecc9d9b9324dd3902c3.zip
use bsCustomFileInput in our docs (#27631)
Diffstat (limited to 'site/docs')
-rw-r--r--site/docs/4.1/assets/js/src/application.js4
1 files changed, 3 insertions, 1 deletions
diff --git a/site/docs/4.1/assets/js/src/application.js b/site/docs/4.1/assets/js/src/application.js
index 6938b9ebe..40dbaea45 100644
--- a/site/docs/4.1/assets/js/src/application.js
+++ b/site/docs/4.1/assets/js/src/application.js
@@ -10,7 +10,7 @@
* details, see https://creativecommons.org/licenses/by/3.0/.
*/
/* global ClipboardJS: false, anchors: false, Holder: false */
(function ($) {
'use strict'
@@ -108,5 +108,7 @@
font: 'Helvetica',
fontweight: 'normal'
})
+
+ bsCustomFileInput.init()
})
}(jQuery))
@@ -10,7 +10,7 @@
* details, see https://creativecommons.org/licenses/by/3.0/.
*/
-/* global ClipboardJS: false, anchors: false, Holder: false */
+/* global ClipboardJS: false, anchors: false, Holder: false, bsCustomFileInput: false */
(function ($) {
'use strict'